@@ -14,17 +14,20 @@ from aiorobokassa.constants import (
     DEFAULT_ENCODING,
     DEFAULT_SIGNATURE_ALGORITHM,
     PAYMENT_ENDPOINT,
+    SPLIT_PAYMENT_ENDPOINT,
 )
 from aiorobokassa.enums import SignatureAlgorithm
 from aiorobokassa.exceptions import SignatureError, ValidationError
 from aiorobokassa.models.requests import (
     PaymentRequest,
     ResultURLNotification,
+    SplitPaymentRequest,
     SuccessURLNotification,
 )
 from aiorobokassa.utils.helpers import build_url, parse_shp_params
 from aiorobokassa.utils.signature import (
     calculate_payment_signature,
+    calculate_split_signature,
     verify_result_url_signature,
     verify_success_url_signature,
 )
@@ -105,7 +108,7 @@ class PaymentMixin:
 
         return params
 
-    async def create_payment_url(
+    def create_payment_url(
         self,
         out_sum: Union[Decimal, float, int, str],
         description: str,
@@ -187,6 +190,7 @@ class PaymentMixin:
             password=password,
             received_signature=notification.signature_value,
             algorithm=signature_algorithm,
+            shp_params=notification.shp_params,
         )
 
         if not is_valid:
@@ -262,3 +266,107 @@ class PaymentMixin:
             "signature_value": params.get("SignatureValue", ""),
             "shp_params": parse_shp_params(params),
         }
+
+    def create_split_payment_url(
+        self,
+        out_amount: Union[Decimal, float, int, str],
+        merchant_id: str,
+        split_merchants: list[Dict[str, Any]],
+        merchant_comment: Optional[str] = None,
+        shop_params: Optional[list[Dict[str, str]]] = None,
+        email: Optional[str] = None,
+        inc_curr: Optional[str] = None,
+        language: Optional[str] = None,
+        is_test: Optional[bool] = None,
+        expiration_date: Optional[str] = None,
+        signature_algorithm: Union[str, SignatureAlgorithm] = DEFAULT_SIGNATURE_ALGORITHM,
+    ) -> str:
+        """
+        Create split payment URL for RoboKassa.
+
+        Split payment allows distributing a payment between multiple merchants.
+
+        Args:
+            out_amount: Total payment amount (Decimal, float, int, or string)
+            merchant_id: Master merchant ID (initiates the split operation)
+            split_merchants: List of split merchant dictionaries, each containing:
+                - id: Merchant ID (required)
+                - invoice_id: Invoice ID (optional, auto-generated if not provided or 0)
+                - amount: Amount for this merchant (required, can be 0.00)
+                - receipt: Receipt data (optional) - Receipt model, JSON string or dict
+            merchant_comment: Order description (max 100 characters, optional)
+            shop_params: List of shop parameter dictionaries with 'name' and 'value' (optional)
+            email: Customer email (optional)
+            inc_curr: Payment method (e.g., "BankCard") (optional)
+            language: Language code (ru, en) (optional)
+            is_test: Test mode flag (optional)
+            expiration_date: Payment expiration date in ISO 8601 format (optional)
+            signature_algorithm: Signature algorithm (optional, default: MD5)
+
+        Returns:
+            Split payment URL string
+
+        Raises:
+            ValidationError: If request data is invalid
+        """
+        if TYPE_CHECKING:
+            client = cast("ClientProtocol", self)
+        else:
+            client = self  # type: ignore[assignment]
+
+        # Convert shop_params to list of ShopParam models if provided
+        shop_params_list = None
+        if shop_params:
+            from aiorobokassa.models.requests import ShopParam
+
+            shop_params_list = [ShopParam(name=p["name"], value=p["value"]) for p in shop_params]
+
+        # Convert split_merchants to list of SplitMerchant models
+        from aiorobokassa.models.requests import SplitMerchant
+
+        split_merchants_list = []
+        for merchant_data in split_merchants:
+            split_merchant = SplitMerchant(
+                id=merchant_data["id"],
+                invoice_id=merchant_data.get("invoice_id"),
+                amount=merchant_data["amount"],
+                receipt=merchant_data.get("receipt"),
+            )
+            split_merchants_list.append(split_merchant)
+
+        # Create request model
+        request = SplitPaymentRequest(
+            out_amount=out_amount,
+            merchant_id=merchant_id,
+            merchant_comment=merchant_comment,
+            split_merchants=split_merchants_list,
+            shop_params=shop_params_list,
+            email=email,
+            inc_curr=inc_curr,
+            language=language,
+            is_test=is_test,
+            expiration_date=expiration_date,
+        )
+
+        # Convert to JSON string (for signature calculation - must be "pure" JSON, not URL-encoded)
+        invoice_json = request.to_json_string()
+
+        # Calculate signature using master merchant's password1
+        signature = calculate_split_signature(
+            invoice_json=invoice_json,
+            password=client.password1,
+            algorithm=signature_algorithm,
+        )
+
+        # URL-encode the invoice JSON for the URL parameter
+        from urllib.parse import quote
+
+        invoice_encoded = quote(invoice_json, safe="")
+
+        # Build URL with parameters
+        params: Dict[str, Optional[str]] = {
+            "invoice": invoice_encoded,
+            "signature": signature,
+        }
+
+        return build_url(f"{client.base_url}{SPLIT_PAYMENT_ENDPOINT}", params)
