@@ -8,8 +8,10 @@ TEST_BASE_URL: Final[str] = "https://auth.robokassa.ru"
 
 # API Endpoints
 PAYMENT_ENDPOINT: Final[str] = "/Merchant/Index.aspx"
+SPLIT_PAYMENT_ENDPOINT: Final[str] = "/Merchant/Payment/CreateV2"
 XML_SERVICE_ENDPOINT: Final[str] = "/Merchant/WebService/Service.asmx"
 INVOICE_API_BASE_URL: Final[str] = "https://services.robokassa.ru/InvoiceServiceWebApi/api"
+REFUND_API_BASE_URL: Final[str] = "https://services.robokassa.ru/RefundService/Refund"
 
 # Default values
 DEFAULT_CULTURE: Final[str] = "ru"
